@@ -19,44 +19,42 @@
 ****************************************/
 
 #include "cardmaps.h"
+#include "version.h"
+#include "view.h"
+#include "dealer.h"
+#include "ksvgrenderer.h"
+#include "card.h"
+#include "cardcache.h"
+#include "speeds.h"
+#ifdef __GNUC__
+#warning cardmap should not really require to know the instance!
+#endif
 
-#include <stdio.h>
+#include <cstdlib>
+#include <cstdio>
 #include <unistd.h>
+#include <cassert>
 
-#include <qpainter.h>
+#include <QPainter>
+#include <QImage>
+#include <QFileInfo>
+#include <QSvgRenderer>
+#include <QPixmapCache>
+#include <QThread>
+#include <QMutex>
 //Added by qt3to4:
 #include <QPixmap>
 #include <QDir>
 
 #include <kconfig.h>
-
-#include <stdlib.h>
-
 #include <kdebug.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
-#include "version.h"
-#include <qimage.h>
 #include <krandom.h>
 #include <carddeckinfo.h>
 #include <kglobalsettings.h>
-#include <qfileinfo.h>
-#include <assert.h>
 #include <kglobal.h>
-#include <QSvgRenderer>
-#include <QPixmapCache>
-#include <QThread>
-#include <QMutex>
 #include <kconfiggroup.h>
-#ifdef __GNUC__
-#warning cardmap should not really require to know the instance!
-#endif
-#include "view.h"
-#include "dealer.h"
-#include "ksvgrenderer.h"
-#include "card.h"
-
-#include "cardcache.h"
 
 cardMap *cardMap::_self = 0;
 
@@ -118,6 +116,9 @@ void cardMap::updateTheme(const KConfigGroup &cs)
 {
     QString fronttheme = CardDeckInfo::frontTheme( cs );
     QString backtheme = CardDeckInfo::backTheme( cs );
+    Q_ASSERT ( !backtheme.isEmpty() );
+    Q_ASSERT ( !fronttheme.isEmpty() );
+
     d->m_cache.setFrontTheme( fronttheme );
     d->m_cache.setBackTheme( backtheme );
 
@@ -187,7 +188,8 @@ void cardMap::setWantedCardWidth( double w )
     }
 }
 
-cardMap *cardMap::self() {
+cardMap *cardMap::self() 
+{
     assert(_self);
     return _self;
 }
