@@ -19,8 +19,8 @@
 
 ---------------------------------------------------------------------------*/
 
-#ifndef _FREECELL_H_
-#define _FREECELL_H_
+#ifndef FREECELL_H
+#define FREECELL_H
 
 #include "dealer.h"
 #include "hint.h"
@@ -76,6 +76,8 @@ protected:
 
 private:
     HintList moves;
+    int sum_moves;
+    int current_weight;
     Card *waitfor;
     bool noLongerNeeded(const Card &);
 };
