@@ -13,15 +13,18 @@
 */
 #include "pile.h"
 #include "dealer.h"
-#include <kdebug.h>
-#include <qpainter.h>
 #include "cardmaps.h"
-#include <kstandarddirs.h>
-#include <deck.h>
-#include <assert.h>
 #include "speeds.h"
+#include "deck.h"
+
+#include <cassert>
+#include <cmath>
+
 #include <QSvgRenderer>
-#include <math.h>
+#include <QPainter>
+
+#include <kstandarddirs.h>
+#include <kdebug.h>
 
 const int Pile::my_type       = DealerScene::PileTypeId;
 
@@ -171,9 +174,11 @@ void Pile::rescale()
 
     QPointF new_pos = QPointF( _pilePos.x() * cardMap::self()->wantedCardWidth() / 10.,
                                _pilePos.y() * cardMap::self()->wantedCardHeight() / 10. );
-    //kDebug() << scene()->sceneRect() << " " << new_pos;
+    //kDebug() << scene()->sceneRect() << pos() << new_pos << dscene()->offsetX();
     if ( new_pos.x() < 0 )
         new_pos.setX( scene()->width() - cardMap::self()->wantedCardWidth() + new_pos.x() );
+    else
+        new_pos.rx() += dscene()->offsetX();
     if ( new_pos.y() < 0 )
         new_pos.setY( scene()->height() - cardMap::self()->wantedCardHeight() + new_pos.y() );
 
@@ -188,7 +193,7 @@ void Pile::rescale()
         setPixmap( *mycache );
         return;
     }
-    kDebug(11111) << gettime() << "rescale start\n";
+    //kDebug(11111) << gettime() << "rescale start\n";
 
 #if 0
     QImage pix( ( int )maximalSpace().width(),
@@ -213,7 +218,7 @@ void Pile::rescale()
     else
         pix.save( KStandardDirs::locateLocal( "data", "kpat/pile.png" ), "PNG" );
     setPixmap( *mycache );
-    kDebug(11111) << gettime() << "rescale end\n";
+    //kDebug(11111) << gettime() << "rescale end\n";
 }
 
 bool Pile::legalAdd( const CardList& _cards, bool ) const
@@ -473,9 +478,21 @@ void Pile::add( Card* _card, bool _facedown )
         qreal dist = sqrt( distx * distx + disty * disty );
         qreal whole = sqrt( scene()->width() * scene()->width() + scene()->height() * scene()->height() );
         _card->moveTo(x2, y2, z2, qRound( dist * 1000 / whole ) );
+
+        if ( _card->animated() )
+        {
+            dscene()->setWaiting( true );
+            connect(_card, SIGNAL(stoped(Card*)), SLOT(waitForMoving(Card*)));
+        }
     }
 }
 
+void Pile::waitForMoving( Card*c )
+{
+    c->disconnect(this);
+    dscene()->setWaiting( false );
+}
+
 void Pile::remove(Card *c)
 {
     assert(m_cards.contains(c));
@@ -540,14 +557,14 @@ void Pile::moveCards(CardList &cl, Pile *to)
     if (removeFlags & autoTurnTop && top()) {
         Card *t = top();
         if (!t->isFaceUp()) {
-            t->flipTo(t->x(), t->y());
+            t->flipTo(t->x(), t->y(), DURATION_FLIP );
         }
     }
 
-    to->moveCardsBack(cl, true);
+    to->moveCardsBack(cl);
 }
 
-void Pile::moveCardsBack(CardList &cl, bool anim)
+void Pile::moveCardsBack(CardList &cl, int steps )
 {
     if (!cl.count())
         return;
@@ -557,9 +574,8 @@ void Pile::moveCardsBack(CardList &cl, bool anim)
     Card *before = 0;
     QSizeF off;
 
-    int steps = DURATION_MOVEBACK;
-    if (!anim)
-        steps = 0;
+    if ( steps == -1 )
+        steps = DURATION_MOVEBACK;
 
     for (CardList::Iterator iti = m_cards.begin(); iti != m_cards.end(); ++iti)
     {
