@@ -244,8 +244,8 @@ QPixmap doRender( const QString& element, KSvgRenderer* r, const QSize& s )
 
 QString keyForPixmap( const QString& theme, const QString& element, const QSize& s )
 {
-    return theme + "_" + element + "_" 
-                  + QString::number( s.width() ) + "_" 
+    return theme + '_' + element + '_'
+                  + QString::number( s.width() ) + '_'
                   + QString::number( s.height() );
 }
 
@@ -465,7 +465,7 @@ QPixmap KCardCache::frontside( const KCardInfo& info ) const
             QMatrix matrix;
             QImage img;
             QString filename = CardDeckInfo::frontDir( d->frontTheme )
-                    + "/" + info.pngName();
+                    + '/' + info.pngName();
             bool ret = img.load( filename, "PNG" );
             if( !ret )
                 return QPixmap();
@@ -531,7 +531,9 @@ void KCardCache::setFrontTheme( const QString& theme )
     {
         QMutexLocker l( d->frontRendererMutex );
         delete d->frontRenderer;
-        d->frontRenderer = new KSvgRenderer( CardDeckInfo::frontSVGFilePath( theme ) );
+        d->frontRenderer = 0;
+        if ( CardDeckInfo::isSVGFront( theme ) )
+            d->frontRenderer = new KSvgRenderer( CardDeckInfo::frontSVGFilePath( theme ) );
     }
     d->frontTheme = theme;
 }
@@ -566,7 +568,9 @@ void KCardCache::setBackTheme( const QString& theme )
     {
         QMutexLocker l( d->backRendererMutex );
         delete d->backRenderer;
-        d->backRenderer = new KSvgRenderer( CardDeckInfo::backSVGFilePath( theme ) );
+        d->backRenderer = 0;
+        if ( CardDeckInfo::isSVGBack( theme ) )
+            d->backRenderer = new KSvgRenderer( CardDeckInfo::backSVGFilePath( theme ) );
     }
     d->backTheme = theme;
 }
@@ -600,7 +604,7 @@ QSizeF KCardCache::defaultFrontSize( const KCardInfo& info ) const
     {
         QImage img;
         if( img.load( CardDeckInfo::frontDir( d->frontTheme )
-            + "/" + info.pngName(), "PNG" ) )
+            + '/' + info.pngName(), "PNG" ) )
             size = img.size();
     }else
     {
